"""Shows your webcam video - Matrix style"""
import argparse
import os
import cv2
import numpy as np

ASCII_CHARS = ["@", "#", "$", "%", "?", "*", "+", ";", ":", ",", "."]


def ascii_image(image: np.typing.NDArray[np.uint8], width: int, height: int) -> str:
    """Turns a numpy image into rich-CLI ascii image"""
    image = cv2.resize(image, (width, height))
    gray = cv2.cvtColor(image, cv2.COLOR_BGR2GRAY)
    ascii_str = ""
    for (_, x), pixel in np.ndenumerate(gray):  # pylint: disable=C0103
        ascii_str += f"{ASCII_CHARS[pixel // 25]}"
        if x == image.shape[1] - 1:
            ascii_str += "\n"
    return ascii_str


def parse_args() -> argparse.Namespace:
    """Parses width and height in characters from CLI."""
    parser = argparse.ArgumentParser(description="py-darts")
    parser.add_argument(
        "width",
        nargs="?",
        default=80,
        type=int,
        help="Width of the video in characters.",
    )

    parser.add_argument(
        "height",
        nargs="?",
        default=23,
        type=int,
        help="Height of the video in characters.",
    )
    return parser.parse_args()


def main() -> None:
    """Main loop."""
    args = parse_args()
    os.system("cls" if os.name == "nt" else "clear")
    cam = cv2.VideoCapture(0)
    try:
        while True:
            _, image = cam.read()

            print("\033[H\033[3J", end="")  # clear
            print("\033[92m")  # green color
            print(ascii_image(image, args.width, args.height))  # ascii image
    except KeyboardInterrupt:
        print("Shutdown")

    cam.release()
    cv2.destroyAllWindows()


if __name__ == "__main__":
    main()



"""Setup script for matrix-webcam"""

import pathlib
from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).resolve().parent

# The text of the README file is used as a description
README = (HERE / "README.md").read_text()

LICENSE = (HERE / "LICENSE").read_text()

# This call to setup() does all the work
setup(
    name="matrix-webcam",
    version="0.1.0",
    description="Displays your webcam video feed in the console.",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/joschuck/matrix-webcam",
    author="Johannes Schuck",
    author_email="jojoschuck@gmail.com",
    license=LICENSE,
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
    ],
    packages=["matrix_webcam"],
    include_package_data=True,
    install_requires=["opencv-python"],
    extras_require={
        "dev": ["pre-commit", "pylint", "black", "mypy"],
    },
    keywords="matrix webcam opencv",
    entry_points={"console_scripts": ["matrix-webcam=matrix_webcam.__main__:main"]},
)
